{% extends "wagtailadmin/base.html" %}
{% load i18n %}

{% block titletag %}{% trans "Delete 2FA device" %}{% endblock %}
{% block content %}
    {% trans "Two Factor Settings" as prefs_str %}
    {% include "wagtailadmin/shared/header.html" with title=prefs_str %}

    <div class="nice-padding">
        <p>{% trans 'Do you want to delete the device?' %}</p>
        <form method="post" action="{% url 'wagtail_2fa_device_remove' pk=object.pk %}">
            <input type="hidden" name="user_id" value="{{object.user.id}}" />
            <a href="{% url 'wagtail_2fa_device_list' user_id=object.user.id %}" class="button">{% trans 'Cancel' %}</a>
            <input type="submit" class="button button-secondary no" value="{% trans 'Remove device' %}">
            {% csrf_token %}
        </form>
    </div>
{% endblock %}
